# This file is part of FatxFast.
#
#    FatxFast is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    FatxFast is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with FatxFast.  If not, see <http://www.gnu.org/licenses/>.

# Versioning based on: 
# http://en.wikipedia.org/wiki/Versioning#Designating_development_stage
__author__ = "dryatu (c) 2013"
__version__ = "1.1.1"
import pygame
from constants import *

class CameraGroup(pygame.sprite.RenderPlain):
    
    def draw(self, surface, camera):
        for gameobj in self:
            if not gameobj.invisible:
                surface.blit(gameobj.image, camera.apply_camera(gameobj)) 

class Camera(object):

    def __init__(self, size=SCREENSIZE):
        self.target = False
        self.rect = pygame.Rect((0,0), size)
        self.moved = False
        self._force_update = True
    
    def follow_target(self, target):
        self.target = target
        self._force_update = True
    
    def apply_camera(self, target):
        try:
            return (target.rect.x-self.rect.x, target.rect.y-self.rect.y)
        except AttributeError:
            return (0,0)
    
    def update(self):
        try:
            if (self.rect.center != self.target.rect.topleft 
                or self._force_update):
                self.moved = True
                self.rect.center = self.target.rect.topleft
                self._force_update = False
            else:
                self.moved = False
        except AttributeError:
            self.rect.center = (0,0)
