# This file is part of FatxFast.
#
#    FatxFast is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    FatxFast is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with FatxFast.  If not, see <http://www.gnu.org/licenses/>.

# Versioning based on: 
# http://en.wikipedia.org/wiki/Versioning#Designating_development_stage
__author__ = "dryatu (c) 2013"
__version__ = "1.1.1"


import pygame
from FatxFast.objects import moveable_entity, animation
from FatxFast.constants import *

class Character(moveable_entity.MoveableEntity):
    """Base class for moveable animated entities"""
    def __init__(self, gamescene, **kwargs):
        self.animation = animation.Animation(
            kwargs.get("animeimage", "char.png"), delay=FRAME_TIME)
        super(Character, self).__init__(gamescene, **kwargs)
        self.image = self.animation.frame
        self.buffs = pygame.sprite.RenderPlain()
        self.dirty = 2

    def update(self, dt):
        # Handles all the animation specifics
        self.buffs.update(dt)
        for buff in self.buffs:
            if buff.duration <= 0:
                buff.kill() 
        if self.speedvector.length():
            self.animation.update(dt)
            if self.speedvector.x:
                self.animation.flipped_x = self.speedvector.x < 0
            self.image = self.animation.frame
        super(Character, self).update(dt)

