
# This file is part of FatxFast.
#
#    FatxFast is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    FatxFast is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with FatxFast.  If not, see <http://www.gnu.org/licenses/>.

# Versioning based on: 
# http://en.wikipedia.org/wiki/Versioning#Designating_development_stage
__author__ = "dryatu (c) 2013"
__version__ = "1.1.1"

from FatxFast.objects.character import Character
from FatxFast.tilemap.maze import solver

class Ghost(Character):
    """Ghost will try to solve the tilemap when iniated. each update iteration
    will move it one step closer to the finish line."""
    def __init__(self, gamescene, **kwargs):
        super(Ghost, self).__init__(gamescene, 
            animeimage="ghost.png", collides=False, **kwargs)
        self.solver = solver.BacktrackSolver()
        self.solver.run(gamescene.tilemap)
        self.solution = self.solver.get_linear_solution()
        
        self.solvertime = 0
        
        self.running = True
    
    def move(self, x=0, y=0):
        super(Ghost, self).move(x, y)
        self.speedvector.x, self.speedvector.y = 0, 0

    def update(self, dt):
        self.solvertime += dt
        if self.solvertime > 250:
            self.solvertime = 0
            try:
                _pos = self.gamescene.tilemap.get_coord_position(
                    self.solution.pop())
            except IndexError:
                self.running = False
            else:
                pos = self.get_position()
                direction = [_pos[0]-pos[0], _pos[1]-pos[1]]
                self.speedvector.x, self.speedvector.y = direction
        super(Ghost, self).update(dt)
